.. _api-doc:

.. .. toctree::
      :glob:

.. attention::
   
   We know some of these webpages could use some work -- this documentation has only recently been created and is in active development. It is updated regularly, so check back weekly.

API Reference
=============

We know, we need to get writing some docstrings. This is a top priority.
